{ config, pkgs, lib, ... }:

{
  
  nixpkgs.config.allowUnfreePredicate = pkg:
    builtins.elem ( lib.getName pkg) [
      "osu-lazer"
      "steam"
      "steam-original"
      "steam-run"
      "nvidia-x11"
      "nvidia-settings"
      "cudatoolkit"
      ];
  programs.steam = {
    enable = true;
    remotePlay.openFirewall = true;
  };
  hardware.steam-hardware.enable = true;

  programs = {
    hyprland.enable = true;
    openvpn3.enable = true;
  };

  services = {
    avahi = {
      enable = true;
      nssmdns4 = true;
      openFirewall = true;
    };
    blueman.enable = true;
    gnome.gnome-keyring.enable = true;
    pipewire = {
      enable = true;
      pulse.enable = true;
      alsa.enable = true;
    };
    printing.enable = true;
    usbmuxd.enable = true;
    xserver.enable = true;
  };

  security.pam.services.swaylock = {};

  hardware.bluetooth.enable = true;

  users.users.stitchynyan = {
    isNormalUser = true;
    shell = pkgs.zsh;
    home = "/home/stitchynyan";
    description = "Personal user";
    extraGroups = [ "wheel" "networkmanager" "kvm" "libvirtd" "audio" ];
    initialHashedPassword = "$y$j9T$rvySCWHYE4AO4A9J0Vf20.$x5hpBNsOWovQFtNfFUIt17OAH5MJFwFBGjxbaEIagJ3";
  };
}
